#!/bin/bash

###############################################################################
# Definitions
###############################################################################

PASSWD_SCP="scp:x:1007:104:SCP user:/opt/./:/bin/bash"
SHADOW_SCP="#" #"scp:\$1\$q6lQg5m6\$cdr44mscZ2A5JzqAu23w90:14132:0:99999:7:::"

###############################################################################
# FUNCTIONS
###############################################################################

###############################################################################
# Downgrade to Release 3.5.0 or lower
# $1 - filename
###############################################################################
function ReplaceSCPandRemoveDefaults
{
    # Delete temp files
    rm -f /tmp/$1.tmp
    
    # Test for defaults
    cat /etc/$1 | grep "defaults:"

    # grep return 0 when it finds defaults indicating we must continue
    if [ $? != 0 ]
    then
        return 0
    fi

    # Modify scp line and remove defaults
    while read line
    do
        # Look for scp line
        if [ "${line:0:4}" == "scp:" ]
        then
            if [ "$1" == "passwd" ]
            then
                echo $PASSWD_SCP >> /tmp/$1.tmp
            else
                echo $line >> /tmp/$1.tmp
            fi
        else
            # Look for defaults
            if [ "${line:0:9}" != "defaults:" ]
            then
                echo $line >> /tmp/$1.tmp
            fi
        fi

    done < /etc/$1

    sync
    mv /tmp/$1.tmp /etc/$1
    chmod 664 /etc/$1

    return 0
}

###############################################################################
# MAIN
###############################################################################

# Update /etc/passwd
ReplaceSCPandRemoveDefaults passwd

# Update /etc/shadow
ReplaceSCPandRemoveDefaults shadow

# Move the upgrade kernel and ram disk to /boot
mv /opt/upgrade/temp/upkernel /opt/upgrade/temp/uprd.img.gz /boot

# Change owner and group to root
chown root:root /boot/upkernel /boot/uprd.img.gz

# Write a new menu.lst file to boot upgrade kernel with ram disk
echo "
default=0
timeout=1
color green/black light-green/black
title Vile Linux 2.5 Upgrade
    kernel --no-mem-option /boot/upkernel
    initrd /boot/uprd.img.gz
title Vile Linux  (Failover Image)
    root (hd0,0)
    kernel --no-mem-option /boot/kernel root=/dev/hda1
" > /boot/grub/menu.lst

# Flush all file system buffers and reboot
sync
shutdown -t1 -a -r -n now

###############################################################################
# END
###############################################################################
